@@ -1,6 +1,34 @@
 #! /usr/bin/env bash
-# Copyright (C) 2016 Sebastian Pipping <sebastian@pipping.org>
-# Licensed under MIT license
+#                          __  __            _
+#                       ___\ \/ /_ __   __ _| |_
+#                      / _ \\  /| '_ \ / _` | __|
+#                     |  __//  \| |_) | (_| | |_
+#                      \___/_/\_\ .__/ \__,_|\__|
+#                               |_| XML parser
+#
+# Copyright (c) 2016-2022 Sebastian Pipping <sebastian@pipping.org>
+# Copyright (c) 2019      Philippe Antoine <contact@catenacyber.fr>
+# Copyright (c) 2019      Hanno Böck <hanno@gentoo.org>
+# Licensed under the MIT license:
+#
+# Permission is  hereby granted,  free of charge,  to any  person obtaining
+# a  copy  of  this  software   and  associated  documentation  files  (the
+# "Software"),  to  deal in  the  Software  without restriction,  including
+# without  limitation the  rights  to use,  copy,  modify, merge,  publish,
+# distribute, sublicense, and/or sell copies of the Software, and to permit
+# persons  to whom  the Software  is  furnished to  do so,  subject to  the
+# following conditions:
+#
+# The above copyright  notice and this permission notice  shall be included
+# in all copies or substantial portions of the Software.
+#
+# THE  SOFTWARE  IS  PROVIDED  "AS  IS",  WITHOUT  WARRANTY  OF  ANY  KIND,
+# EXPRESS  OR IMPLIED,  INCLUDING  BUT  NOT LIMITED  TO  THE WARRANTIES  OF
+# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
+# NO EVENT SHALL THE AUTHORS OR  COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
+# DAMAGES OR  OTHER LIABILITY, WHETHER  IN AN  ACTION OF CONTRACT,  TORT OR
+# OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
+# USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 set -e
 set -o nounset
@@ -126,13 +154,14 @@ run_tests() {
     esac
 
     if [[ ${CC} =~ mingw ]]; then
-        # NOTE: Filenames are hardcoded for Travis Ubuntu trusty, as of now
         for i in tests xmlwf ; do
+            mingw32_dir="$(dirname "$(ls -1 /usr/lib*/gcc/i686-w64-mingw32/*/{libgcc_s_sjlj-1.dll,libstdc++-6.dll} | head -n1)")"
             RUN ln -s \
                     /usr/i686-w64-mingw32/lib/libwinpthread-1.dll \
-                    /usr/lib/gcc/i686-w64-mingw32/*/libgcc_s_sjlj-1.dll \
-                    /usr/lib/gcc/i686-w64-mingw32/*/libstdc++-6.dll \
-                    "$PWD"/libexpat{,w}.dll \
+                    "${mingw32_dir}"/libgcc_s_dw2-1.dll \
+                    "${mingw32_dir}"/libgcc_s_sjlj-1.dll \
+                    "${mingw32_dir}"/libstdc++-6.dll \
+                    "$PWD"/libexpat{,w}-*.dll \
                     ${i}/
         done
     fi
